==> parodia_admin-1.0.2.tar.gz: lib/core/repository/storeRating.repository.dart <==
// GET
// /api/v1/dashboard/stores/ratings

// PUT
// /api/v1/dashboard/stores/ratings/{id}

// DELETE
// /api/v1/dashboard/stores/ratings/{id}

// POST
// /api/v1/dashboard/stores/ratings/{id}/recover
import 'package:parodia_admin/core/dto/rating.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StoreRatingRepository {
  ParodiaHTTP? _http;

  StoreRatingRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseListDTO<RatingDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/stores/ratings',
      query: query,
    );

    return ResponseListDTO<RatingDTO>(
      response: response,
      fromJson: RatingDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, StoreRatingPutBody? rating}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/stores/ratings',
      param: id,
      data: rating,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/stores/ratings',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/stores/ratings/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/storeRating.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/stores/ratings

// PUT
// /api/v1/dashboard/dashboard/stores/ratings/{id}

// DELETE
// /api/v1/dashboard/dashboard/stores/ratings/{id}

// POST
// /api/v1/dashboard/dashboard/stores/ratings/{id}/recover
import 'package:parodia_admin/core/dto/rating.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class StoreRatingRepository {
  ParodiaHTTP? _http;

  StoreRatingRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseListDTO<RatingDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/stores/ratings',
      query: query,
    );

    return ResponseListDTO<RatingDTO>(
      response: response,
      fromJson: RatingDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, StoreRatingPutBody? rating}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/stores/ratings',
      param: id,
      data: rating,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/stores/ratings',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/stores/ratings/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
